# -*- coding: utf-8 -*-

"""Top-level package for navarp."""

__author__ = """Federico Bisti"""
__email__ = 'federico.bisti@univaq.it'
__version__ = '1.0.0'
